@@ -28,6 +28,11 @@ from collections import deque
 import functools
 
 
+MYPY = False
+if MYPY:
+    from typing import Any, Callable, Deque, Dict, Tuple
+
+
 class InvocationError(AttributeError):
     pass
 
@@ -44,8 +49,8 @@ class Invocation(object):
         self.method_name = method_name
         self.strict = mock.strict
 
-        self.params = ()
-        self.named_params = {}
+        self.params = ()  # type: Tuple[Any, ...]
+        self.named_params = {}  # type: Dict[str, Any]
 
     def _remember_params(self, params, named_params):
         self.params = params
@@ -92,6 +97,7 @@ class RememberedInvocation(Invocation):
         for matching_invocation in self.mock.stubbed_invocations:
             if matching_invocation.matches(self):
                 matching_invocation.should_answer(self)
+                matching_invocation.capture_arguments(self)
                 return matching_invocation.answer_first(
                     *params, **named_params)
 
@@ -156,6 +162,26 @@ class MatchingInvocation(Invocation):
             return False
         return True
 
+    def capture_arguments(self, invocation):
+        for x, p1 in enumerate(self.params):
+            if isinstance(p1, matchers.Capturing):
+                try:
+                    p2 = invocation.params[x]
+                except IndexError:
+                    continue
+
+                p1.capture_value(p2)
+
+        for key, p1 in self.named_params.items():
+            if isinstance(p1, matchers.Capturing):
+                try:
+                    p2 = invocation.named_params[key]
+                except KeyError:
+                    continue
+
+                p1.capture_value(p2)
+
+
     def _remember_params(self, params, named_params):
         if (
             contains_strict(params, Ellipsis)
@@ -237,6 +263,7 @@ class VerifiableInvocation(MatchingInvocation):
         matched_invocations = []
         for invocation in self.mock.invocations:
             if self.matches(invocation):
+                self.capture_arguments(invocation)
                 matched_invocations.append(invocation)
 
         self.verification.verify(self, len(matched_invocations))
@@ -415,7 +442,7 @@ class AnswerSelector(object):
 class CompositeAnswer(object):
     def __init__(self):
         #: Container for answers, which are just ordinary callables
-        self.answers = deque()
+        self.answers = deque()  # type: Deque[Callable]
 
         #: Counter for the maximum answers we ever had
         self.answer_count = 0
